@@ -1,20 +1,24 @@
 # Libraries
-import typer
-import pathlib
 import logging
 import os
-import boto3
-from botocore.exceptions import ClientError
+import pathlib
 import tempfile
+
+import boto3
 import piphyperd
-
-
+import typer
+from botocore.exceptions import ClientError
 
 # Constants
-environment = os.environ.get("DEPLOY_ENV", "default")
-s3_bucket = os.environ.get("S3_PYPI", "ds-private-pypi")
-session = boto3.Session(profile_name=environment)
-s3_client = session.client('s3')
+environment = os.environ.get("DEPLOY_ENV")
+s3_bucket = os.environ.get("S3_PYPI", "ds-sandbox-private-pypi")
+
+if environment:
+    session = boto3.Session(profile_name=environment)
+else:
+    session = boto3.Session()
+
+s3_client = session.client("s3")
 app = typer.Typer()
 
 
@@ -58,31 +62,28 @@ def upload_package(package_name: str):
     except StopIteration:
         print("No wheel file is found. Please build your package")
 
-    
+
 def download_install(package_name: str):
     package_path = f"{s3_bucket}/{package_name}"
     try:
-        response = s3_client.list_objects_v2(
-            Bucket = s3_bucket,
-            Prefix = package_name
-                )
+        response = s3_client.list_objects_v2(Bucket=s3_bucket, Prefix=package_name)
         package_key = response["Contents"][0]["Key"]
         wheel_name = package_key.split("/")[-1]
         temp_dir = tempfile.TemporaryDirectory()
         s3_client.download_file(
-                Bucket=s3_bucket,
-                Key= package_key,
-                Filename = f"{temp_dir.name}/{wheel_name}")
+            Bucket=s3_bucket, Key=package_key, Filename=f"{temp_dir.name}/{wheel_name}"
+        )
         print(f"Downloaded package to {temp_dir.name}")
         piphyperd.PipHyperd().install(f"{temp_dir.name}/{wheel_name}")
     except:
         print(f"Can't find the packege {package_name}")
 
+
 @app.command("install")
 def install(
-    packages: str, 
-    r: bool = typer.Option(False,"-r","--recursive", help="install package from a file")
-    ):
+    packages: str,
+    r: bool = typer.Option(False, "-r", "--recursive", help="install package from a file"),
+):
     if r:
         with open(packages, "r") as f:
             packages = f.readlines()
@@ -92,5 +93,6 @@ def install(
     else:
         download_install(packages)
 
+
 def main():
     app()
